dart_vlc library
Classes
- Broadcast
- Creates new Broadcast for a Media.
- BroadcastConfiguration
- Used to declare a Broadcast configuration.
- Chromecast
- CurrentState
-
State of a
Playerinstance. - DartVLC
- Initializes the DartVLC plugin.
- Device
-
Represents a playback Device for the
Player. - Devices
-
Devices.all getter is used to get List of all available Device for playback in the
Player. - Equalizer
-
Defines an Equalizer instance for usage in a
Player. - GeneralState
-
Volume & Rate state of a
Playerinstance. - Media
-
A media object to open inside a
Player. - MediaSource
- Parent abstract class of Media and Playlist.
- NativeVideo
- A widget for showing video inside the Widget tree. This Widget is more performant compared to Video & uses flutter_native_view to embed the video output directly without any texture interop or pixel-buffer copy calls.
- PlaybackState
-
Playback state of a
Playerinstance. - Player
- A Player to open & play a Media or Playlist from file, network or asset.
- Playlist
-
A playlist object to open inside a
Player.open. - PositionState
-
Position & duration state of a
Playerinstance. - Record
- Video
- Widget for showing Video inside the Widget tree. Creation of Player instance is necessary as a controller, for this Widget to show Video output.
- VideoDimensions
- Represents dimensions of a video.
- VideoFrame
- Represents a Video frame, used for retriving frame through platform channel.
Enums
- EqualizerMode
- Predefined presets for Equalizer.
- MediaSourceType
-
Enum to specify the type of MediaSource passed in
Player.open. - MediaType
- Enum to specify the type of Media.
- PlaylistMode
- Enum to specify the playback mode of Playlist.
Extensions
Properties
-
controls
↔ Map<
int, GlobalKey< ControlState> > -
Internally used map to keep GlobalKeys for Video's
ControlStates.getter/setter pair -
players
↔ Map<
int, Player> -
Keeps various
Playerinstances to manage event callbacks.getter/setter pair -
videoStreamControllers
↔ Map<
int, StreamController< VideoFrame> > -
Internally used map to keep StreamControllers for Video Widgets.
getter/setter pair
Typedefs
-
InitializeDartApiCXX
= Void Function(Pointer<
NativeFunction< postCObject, Int64 nativePort, Pointer<Int8 Function(Int64, Pointer< >Dart_CObject> )>Void> initializeApiDLData) -
InitializeDartApiDart
= void Function(Pointer<
NativeFunction< postCObject, int nativePort, Pointer<Int8 Function(Int64, Pointer< >Dart_CObject> )>Void> initializeApiDLData)